Learn R Programming

mixpoissonreg (version 1.0.0)

Attendance: Attendance Records data set

Description

School administrators study the attendance behavior of high school juniors at two schools.

Usage

data("Attendance")

Arguments

Format

Data frame containing 314 observations on 4 variables.

daysabs

number of days absent.

gender

gender of the student.

prog

three-level factor indicating the type of instructional program in which the student is enrolled.

math

standardized math score.

Details

School administrators study the attendance behavior of high school juniors at two schools. Predictors of the number of days of absence include the type of program in which the student is enrolled and a standardized test in math. Attendance data on 314 high school juniors from two urban high schools. The response variable of interest is days absent, daysabs. The variable math is the standardized math score for each student. The variable prog is a three-level factor indicating the type of instructional program in which the student is enrolled.

References

Hughes, M. and Fisher, T. (2020) Introduction to Statistical Modeling.

Examples

Run this code
# NOT RUN {
data("Attendance", package = "mixpoissonreg")

daysabs_fit <- mixpoissonregML(daysabs ~ gender + math + prog | gender + 
math + prog, data = Attendance)
summary(daysabs_fit)

# }

Run the code above in your browser using DataLab