Learn R Programming

mixpoissonreg (version 1.0.0)

coef.mixpoissonreg: Coef Method for mixpoissonreg Objects.

Description

Extract model coefficients of fitted mixed Poisson regression models. The parameters arguments allows one to chose if all coefficients should be extracted, with parameters = 'all'; if the coefficients of the mean-related parameters should be extracted, with parameters = 'mean'; if the coefficients of the precision-related parameters should be extracted, with parameters = 'precision'.

Usage

# S3 method for mixpoissonreg
coef(object, parameters = c("all", "mean", "precision"), ...)

Arguments

object

object of class "mixpoissonreg" containing results from the fitted model.

parameters

a string to determine which coefficients should be extracted: 'all' extracts all coefficients, 'mean' extracts the coefficients of the mean parameters and 'precision' extracts coefficients of the precision parameters.

...

further arguments passed to or from other methods.

Value

A vector containing the coefficients of a mixpoissonreg object.

See Also

vcov.mixpoissonreg

Examples

Run this code
# NOT RUN {
daysabs_prog <- mixpoissonreg(daysabs ~ prog, data = Attendance)
coef(daysabs_prog)

# }

Run the code above in your browser using DataLab