mixpoissonreg objectTidy returns a tibble::tibble() containing
informations on the coefficients of the model, such as the estimated parameters,
standard errors, z-statistics and p-values. Additionally, it may return confidence
intervals for the model parameters.
# S3 method for mixpoissonreg
tidy(x, conf.int = FALSE, conf.level = 0.95, ...)A mixpoissonreg object.
Logical indicating whether or not to include a confidence interval in the tidied output. Defaults to FALSE.
The confidence level to use for the confidence interval if conf.int = TRUE. Must be strictly greater than 0 and less than 1. Defaults to 0.95, which corresponds to a 95 percent confidence interval.
Additional arguments. Currently not used.
A tibble containing the coefficients of the fitted mixpoissonreg object along with its estimates, std. errors, z-statistics and p-values.
glance.mixpoissonreg, augment.mixpoissonreg, tidy_local_influence.mixpoissonreg,
autoplot.mixpoissonreg, local_influence_autoplot.mixpoissonreg