fitted.mixpoissonreg: Fitted Method for mixpoissonreg Objects
Description
Function providing the fitted means, linear predictors, precisions or variances for mixed Poisson regression models.
Usage
# S3 method for mixpoissonreg
fitted(object, type = c("response", "link", "precision", "variance"), ...)
Arguments
object
object of class "mixpoissonreg" containing results from the fitted model.
type
the type of variable to get the fitted values. The default is the "response" type, which provided the estimated values for the means.
The type "link" provides the estimates for the linear predictor of the mean. The type "precision" provides estimates for the precision parameters
whereas the type "variance" provides estimates for the variances.
...
Currently not used.
Value
A vector containing the fitted values of a mixpoissonreg object.