Learn R Programming

mixpoissonreg (version 1.0.0)

vcov.mixpoissonreg: Calculate Variance-Covariance Matrix for mixpoissonreg Objects

Description

Returns the variance-covariance matrix of the parameters for fitted mixed Poisson regression models. The parameters argument indicates for which parameters the variance-covariance matrix should be computed, namely, 'mean' for mean-relatex parameters or 'precision' for precision-related parameters.

Usage

# S3 method for mixpoissonreg
vcov(object, parameters = c("all", "mean", "precision"), ...)

Arguments

object

an object of class "mixpoissonreg" containing results from the fitted model.

parameters

a string to determine which coefficients should be extracted: 'all' extracts all coefficients, 'mean' extracts the coefficients of the mean parameters and 'precision' extracts coefficients of the precision parameters.

...

further arguments passed to or from other methods.

Value

A matrix containing the covariance matrix of a mixpoissonreg object.

See Also

coef.mixpoissonreg

Examples

Run this code
# NOT RUN {
daysabs_prog <- mixpoissonreg(daysabs ~ prog, data = Attendance)
vcov(daysabs_prog)

# }

Run the code above in your browser using DataLab