vcov.mixpoissonreg: Calculate Variance-Covariance Matrix for mixpoissonreg Objects
Description
Returns the variance-covariance matrix of the parameters for fitted mixed Poisson regression models. The parameters argument
indicates for which parameters the variance-covariance matrix should be computed, namely, 'mean' for mean-relatex parameters or 'precision' for precision-related parameters.
an object of class "mixpoissonreg" containing results from the fitted model.
parameters
a string to determine which coefficients should be extracted: 'all' extracts all coefficients, 'mean' extracts the coefficients of the mean parameters and 'precision' extracts coefficients of the precision parameters.
...
further arguments passed to or from other methods.
Value
A matrix containing the covariance matrix of a mixpoissonreg object.